@@ -15,7 +15,10 @@
 #ifndef _LVM_LVMPOLLD_DATA_UTILS_H
 #define _LVM_LVMPOLLD_DATA_UTILS_H
 
+#include "base/data-struct/hash.h"
+
 #include <pthread.h>
+#include <stdio.h>
 
 struct buffer;
 struct lvmpolld_state;
@@ -68,7 +71,7 @@ struct lvmpolld_lv {
 	struct lvmpolld_cmd_stat cmd_state;
 	unsigned init_rq_count; /* for debugging purposes only */
 	unsigned polling_finished:1; /* no more updates */
-	unsigned error:1; /* unrecoverable error occured in lvmpolld */
+	unsigned error:1; /* unrecoverable error occurred in lvmpolld */
 };
 
 typedef void (*lvmpolld_parse_output_fn_t) (struct lvmpolld_lv *pdlv, const char *line);
@@ -93,7 +96,7 @@ struct lvmpolld_thread_data {
 	struct lvmpolld_lv *pdlv;
 };
 
-char *construct_id(const char *sysdir, const char *lvid);
+char *construct_id(const char *sysdir, const char *uuid);
 
 /* LVMPOLLD_LV_T section */
 
