@@ -13,6 +13,11 @@
  * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
+#ifndef LIB_DEVICE_DEVICE_TYPES_H
+#define LIB_DEVICE_DEVICE_TYPES_H
+
+#include <stdint.h>
+
 typedef struct {
 	const char name[15];
 	const int8_t max_partitions;
@@ -65,5 +70,8 @@ static const dev_known_type_t _dev_known_types[] = {
 	{"nvme", 64, "NVM Express"},
 	{"zvol", 16, "ZFS Zvols"},
 	{"VxDMP", 16, "Veritas Dynamic Multipathing"},
+	{"zram", 1, "zram block device"},
 	{"", 0, ""}
 };
+
+#endif
