@@ -61,14 +61,14 @@ int text_read_metadata_summary(const struct format_type *fmt,
 		if (!config_file_read_fd(cft, dev, reason, offset, size,
 					 offset2, size2, checksum_fn,
 					 vgsummary->mda_checksum,
-					 checksum_only, 1)) {
-			log_warn("WARNING: invalid metadata text from %s at %llu.",
+					 checksum_only, 1, 1)) {
+			log_warn("WARNING: Invalid metadata text from %s at %llu.",
 				 dev_name(dev), (unsigned long long)offset);
 			goto out;
 		}
 	} else {
-		if (!config_file_read(cft)) {
-			log_warn("WARNING: invalid metadata text from file.");
+		if (!config_file_read_from_file(cft)) {
+			log_warn("WARNING: Invalid metadata text from file.");
 			goto out;
 		}
 	}
@@ -156,13 +156,13 @@ struct volume_group *text_read_metadata(struct format_instance *fid,
 
 		if (!config_file_read_fd(cft, dev, MDA_CONTENT_REASON(primary_mda), offset, size,
 					 offset2, size2, checksum_fn, checksum,
-					 skip_parse, 1)) {
-			log_warn("WARNING: couldn't read volume group metadata from %s.", dev_name(dev));
+					 skip_parse, 1, 0)) {
+			log_warn("WARNING: Couldn't read volume group metadata from %s.", dev_name(dev));
 			goto out;
 		}
 	} else {
-		if (!config_file_read(cft)) {
-			log_warn("WARNING: couldn't read volume group metadata from file.");
+		if (!config_file_read_from_file(cft)) {
+			log_warn("WARNING: Couldn't read volume group metadata from file.");
 			goto out;
 		}
 	}
