@@ -13,7 +13,12 @@
 
 #include "libdaemon/client/config-util.h"
 #include "libdaemon/client/daemon-client.h"
-#include "lib/metadata/metadata-exported.h" /* is_lockd_type() */
+#include "daemons/lvmlockd/lvmlockd-client.h"
+
+struct lockd_state {
+	uint32_t flags;
+	uint64_t generation;
+};
 
 #define LOCKD_SANLOCK_LV_NAME "lvmlock"
 
@@ -32,6 +37,7 @@
 #define LD_RF_DUP_GL_LS         0x00000008
 #define LD_RF_NO_LM		0x00000010
 #define LD_RF_SH_EXISTS		0x00000020
+#define LD_RF_HOSTS_UNKNOWN	0x00000040
 
 /* lockd_state flags */
 #define LDST_EX			0x00000001
@@ -63,13 +69,20 @@
 #define LOCKOPT_REPAIRVG	0x00020000
 #define LOCKOPT_REPAIRLV	0x00040000
 
-#ifdef LVMLOCKD_SUPPORT
-
-void lockd_lockopt_get_flags(const char *str, uint32_t *flags);
 
 struct lvresize_params;
 struct lvcreate_params;
 
+#ifdef LVMLOCKD_SUPPORT
+
+int is_lockd_type(const char *lock_type);
+int vg_is_shared(const struct volume_group *vg);
+int vg_is_sanlock(const struct volume_group *vg);
+
+void lockd_lockopt_get_flags(const char *str, uint32_t *flags);
+int lockd_lockargs_get_user_flags(const char *str, uint32_t *flags);
+int lockd_lockargs_get_meta_flags(const char *str, uint32_t *flags);
+
 /* lvmlockd connection and communication */
 
 void lvmlockd_set_socket(const char *sock);
@@ -82,7 +95,8 @@ void lvmlockd_disconnect(void);
 
 /* vgcreate/vgremove use init/free */
 
-int lockd_init_vg(struct cmd_context *cmd, struct volume_group *vg, const char *lock_type, int lv_lock_count);
+int lockd_init_vg(struct cmd_context *cmd, struct volume_group *vg,
+                  const char *lock_type, int lv_lock_count, const char *set_args);
 int lockd_free_vg_before(struct cmd_context *cmd, struct volume_group *vg, int changing, int yes);
 void lockd_free_vg_final(struct cmd_context *cmd, struct volume_group *vg);
 
@@ -104,11 +118,11 @@ int lockd_vg_is_busy(struct cmd_context *cmd, struct volume_group *vg);
 int lockd_global_create(struct cmd_context *cmd, const char *def_mode, const char *vg_lock_type);
 int lockd_global(struct cmd_context *cmd, const char *def_mode);
 int lockd_vg(struct cmd_context *cmd, const char *vg_name, const char *def_mode,
-	     uint32_t flags, uint32_t *lockd_state);
+	     uint32_t flags, struct lockd_state *lks);
 int lockd_vg_update(struct volume_group *vg);
 
 int lockd_lv_name(struct cmd_context *cmd, struct volume_group *vg,
-		  const char *lv_name, struct id *lv_id,
+		  const char *lv_name, const struct id *lv_id,
 		  const char *lock_args, const char *def_mode, uint32_t flags);
 int lockd_lv(struct cmd_context *cmd, struct logical_volume *lv,
 	     const char *def_mode, uint32_t flags);
@@ -142,12 +156,39 @@ void lockd_lvcreate_done(struct cmd_context *cmd, struct volume_group *vg, struc
 int lockd_lvremove_lock(struct cmd_context *cmd, struct logical_volume *lv, struct logical_volume **lv_other, int *other_unlock);
 void lockd_lvremove_done(struct cmd_context *cmd, struct logical_volume *lv, struct logical_volume *lv_other, int other_unlock);
 
+int lockd_setlockargs(struct cmd_context *cmd, struct volume_group *vg, const char *set_args, uint64_t *our_key_held);
+
 #else /* LVMLOCKD_SUPPORT */
 
+static inline int is_lockd_type(const char *lock_type)
+{
+	return 0;
+}
+
+static inline int vg_is_shared(const struct volume_group *vg)
+{
+	return 0;
+}
+
+static inline int vg_is_sanlock(const struct volume_group *vg)
+{
+	return 0;
+}
+
 static inline void lockd_lockopt_get_flags(const char *str, uint32_t *flags)
 {
 }
 
+static inline int lockd_lockargs_get_user_flags(const char *str, uint32_t *flags)
+{
+	return 0;
+}
+
+static inline int lockd_lockargs_get_meta_flags(const char *str, uint32_t *flags)
+{
+	return 0;
+}
+
 static inline void lvmlockd_set_socket(const char *sock)
 {
 }
@@ -173,7 +214,8 @@ static inline int lvmlockd_use(void)
 	return 0;
 }
 
-static inline int lockd_init_vg(struct cmd_context *cmd, struct volume_group *vg, const char *lock_type, int lv_lock_count)
+static inline int lockd_init_vg(struct cmd_context *cmd, struct volume_group *vg,
+                  const char *lock_type, int lv_lock_count, const char *set_args)
 {
 	return 1;
 }
@@ -225,7 +267,7 @@ static inline int lockd_global_create(struct cmd_context *cmd, const char *def_m
 	 * a shared lock type should fail.
 	 */
 	if (is_lockd_type(vg_lock_type)) {
-		log_error("Using a shared lock type requires lvmlockd.");
+		fprintf(stderr, "Using a shared lock type requires lvmlockd.\n");
 		return 0;
 	}
 	return 1;
@@ -237,9 +279,9 @@ static inline int lockd_global(struct cmd_context *cmd, const char *def_mode)
 }
 
 static inline int lockd_vg(struct cmd_context *cmd, const char *vg_name, const char *def_mode,
-	     uint32_t flags, uint32_t *lockd_state)
+	     uint32_t flags, struct lockd_state *lks)
 {
-	*lockd_state = 0;
+	memset(lks, 0, sizeof(*lks));
 	return 1;
 }
 
@@ -295,7 +337,7 @@ static inline void lockd_free_removed_lvs(struct cmd_context *cmd, struct volume
 
 static inline const char *lockd_running_lock_type(struct cmd_context *cmd, int *found_multiple)
 {
-	log_error("Using a shared lock type requires lvmlockd.");
+	fprintf(stderr, "Using a shared lock type requires lvmlockd.\n");
 	return NULL;
 }
 
@@ -345,6 +387,11 @@ static inline int lockd_vg_is_busy(struct cmd_context *cmd, struct volume_group
 	return 0;
 }
 
+static inline int lockd_setlockargs(struct cmd_context *cmd, struct volume_group *vg, const char *set_args, uint64_t *our_key_held)
+{
+	return 0;
+}
+
 #endif	/* LVMLOCKD_SUPPORT */
 
 #endif	/* _LVMLOCKD_H */
