@@ -10,18 +10,16 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-#include "lib.h"
-#include "lvm-file.h"
+#include "lib/misc/lib.h"
+#include "lib/misc/lvm-file.h"
 
 #include <unistd.h>
-#include <sys/stat.h>
 #include <sys/file.h>
 #include <fcntl.h>
 #include <dirent.h>
-#include <sys/time.h>
 
 /*
  * Creates a temporary filename, and opens a descriptor to the
@@ -42,7 +40,7 @@ int create_temp_name(const char *dir, char *buffer, size_t len, int *fd,
 	pid = getpid();
 	if (gethostname(hostname, sizeof(hostname)) < 0) {
 		log_sys_error("gethostname", "");
-		strcpy(hostname, "nohostname");
+		dm_strncpy(hostname, "nohostname", sizeof(hostname));
 	} else {
 		/* Replace any '/' with '?' found in the hostname. */
 		p = hostname;
@@ -105,7 +103,7 @@ int lvm_rename(const char *old, const char *new)
 		return 0;
 	}
 
-	if (unlink(old)) {
+	if (unlink(old) && (errno != ENOENT)) {
 		log_sys_error("unlink", old);
 		return 0;
 	}
@@ -142,24 +140,55 @@ int dir_exists(const char *path)
 	return 1;
 }
 
-int is_empty_dir(const char *dir)
+static int _dir_create(const char *path, int mode)
 {
-	struct dirent *dirent;
-	DIR *d;
+	int r;
 
-	if (!(d = opendir(dir))) {
-		log_sys_error("opendir", dir);
+	log_debug("Creating directory %s.", path);
+
+	dm_prepare_selinux_context(path, S_IFDIR);
+	r = mkdir(path, mode);
+	dm_prepare_selinux_context(NULL, 0);
+
+	if (r == 0)
+		return 1;
+
+	if (errno == EEXIST) {
+		if (dir_exists(path))
+			return 1;
+
+		log_error("Path %s is not a directory.", path);
+	} else
+		log_sys_error("mkdir", path);
+
+	return 0;
+}
+
+int dir_create_recursive(const char *path, int mode)
+{
+	int r = 0;
+	char *orig, *s;
+
+	orig = s = strdup(path);
+	if (!s) {
+		log_error("Failed to duplicate directory path %s.", path);
 		return 0;
 	}
 
-	while ((dirent = readdir(d)))
-		if (strcmp(dirent->d_name, ".") && strcmp(dirent->d_name, ".."))
-			break;
+	while ((s = strchr(s, '/')) != NULL) {
+		*s = '\0';
+		if (*orig && !dir_exists(orig) && !_dir_create(orig, mode))
+			goto_out;
+		*s++ = '/';
+	}
 
-	if (closedir(d))
-		log_sys_error("closedir", dir);
+	if (!dir_exists(path) && !_dir_create(path, mode))
+		goto_out;
+	r = 1;
+out:
+	free(orig);
 
-	return dirent ? 0 : 1;
+	return r;
 }
 
 void sync_dir(const char *file)
@@ -167,7 +196,7 @@ void sync_dir(const char *file)
 	int fd;
 	char *dir, *c;
 
-	if (!(dir = dm_strdup(file))) {
+	if (!(dir = strdup(file))) {
 		log_error("sync_dir failed in strdup");
 		return;
 	}
@@ -195,7 +224,7 @@ void sync_dir(const char *file)
 		log_sys_error("close", dir);
 
       out:
-	dm_free(dir);
+	free(dir);
 }
 
 /*
@@ -211,7 +240,7 @@ int fcntl_lock_file(const char *file, short lock_type, int warn_if_read_only)
 	char *dir;
 	char *c;
 
-	if (!(dir = dm_strdup(file))) {
+	if (!(dir = strdup(file))) {
 		log_error("fcntl_lock_file failed in strdup.");
 		return -1;
 	}
@@ -220,11 +249,11 @@ int fcntl_lock_file(const char *file, short lock_type, int warn_if_read_only)
 		*c = '\0';
 
 	if (!dm_create_dir(dir)) {
-		dm_free(dir);
+		free(dir);
 		return -1;
 	}
 
-	dm_free(dir);
+	free(dir);
 
 	log_very_verbose("Locking %s (%s, %hd)", file,
 			 (lock_type == F_WRLCK) ? "F_WRLCK" : "F_RDLCK",
