@@ -271,7 +271,7 @@ char *build_dm_uuid(struct dm_pool *mem, const struct logical_volume *lv,
 			  lv_is_raid_image(lv) ||
 			  lv_is_raid_metadata(lv)) &&
 			 !lv_is_visible(lv)) ? "real" :
-			lv_is_pvmove(lv) ? "real" :
+			(lv_is_pvmove(lv) || lv_is_orphan_pvmove(lv)) ? "real" :
 			lv_is_thin_pool(lv) ? "pool" :
 			lv_is_thin_pool_data(lv) ? "tdata" :
 			lv_is_thin_pool_metadata(lv) ? "tmeta" :
@@ -292,7 +292,7 @@ char *build_dm_uuid(struct dm_pool *mem, const struct logical_volume *lv,
 	return dlid;
 }
 
-char *first_substring(const char *str, ...)
+char *first_substring(char *str, ...)
 {
 	char *substr, *r = NULL;
 	va_list ap;
