@@ -38,7 +38,7 @@ static int _bad_field(const char *field)
 static int _import_bool(const struct dm_config_node *n,
 			const char *name, bool *b)
 {
-	uint32_t t;
+	uint32_t t = 0;
 
 	if (dm_config_has_node(n, name)) {
 		if (!dm_config_get_uint32(n, name, &t))
@@ -74,8 +74,7 @@ static void _vdo_display(const struct lv_segment *seg)
 }
 
 static int _vdo_text_import(struct lv_segment *seg,
-			    const struct dm_config_node *n,
-			    struct dm_hash_table *pv_hash __attribute__((unused)))
+			    const struct dm_config_node *n)
 {
 	struct logical_volume *vdo_pool_lv;
 	const char *str;
@@ -167,21 +166,22 @@ static void _vdo_pool_display(const struct lv_segment *seg)
 
 	_print_yes_no("Compression\t", vtp->use_compression);
 	_print_yes_no("Deduplication", vtp->use_deduplication);
-	_print_yes_no("Metadata hints", vtp->use_metadata_hints);
+	if (vtp->use_metadata_hints)
+		_print_yes_no("Metadata hints", vtp->use_metadata_hints);
 
 	log_print("  Minimum IO size\t%s",
 		  display_size(cmd, vtp->minimum_io_size));
 	log_print("  Block map cache sz\t%s",
-		  display_size(cmd, vtp->block_map_cache_size_mb * UINT64_C(2 * 1024)));
+		  display_mb_size(cmd, vtp->block_map_cache_size_mb));
 	log_print("  Block map era length %u", vtp->block_map_era_length);
 
 	_print_yes_no("Sparse index", vtp->use_sparse_index);
 
 	log_print("  Index memory size\t%s",
-		  display_size(cmd, vtp->index_memory_size_mb * UINT64_C(2 * 1024)));
+		  display_mb_size(cmd, vtp->index_memory_size_mb));
 
 	log_print("  Slab size\t\t%s",
-		  display_size(cmd, vtp->slab_size_mb * UINT64_C(2 * 1024)));
+		  display_mb_size(cmd, vtp->slab_size_mb));
 
 	log_print("  # Ack threads\t%u", (unsigned) vtp->ack_threads);
 	log_print("  # Bio threads\t%u", (unsigned) vtp->bio_threads);
@@ -191,7 +191,8 @@ static void _vdo_pool_display(const struct lv_segment *seg)
 	log_print("  # Logical threads\t%u", (unsigned) vtp->logical_threads);
 	log_print("  # Physical threads\t%u", (unsigned) vtp->physical_threads);
 	log_print("  Max discard\t\t%u", (unsigned) vtp->max_discard);
-	log_print("  Write policy\t%s", get_vdo_write_policy_name(vtp->write_policy));
+	if (vtp->write_policy != DM_VDO_WRITE_POLICY_AUTO)
+		log_print("  Write policy\t%s", get_vdo_write_policy_name(vtp->write_policy));
 }
 
 /* reused as _vdo_text_import_area_count */
@@ -204,8 +205,7 @@ static int _vdo_pool_text_import_area_count(const struct dm_config_node *sn __at
 }
 
 static int _vdo_pool_text_import(struct lv_segment *seg,
-				 const struct dm_config_node *n,
-				 struct dm_hash_table *pv_hash __attribute__((unused)))
+				 const struct dm_config_node *n)
 {
 	struct dm_vdo_target_params *vtp = &seg->vdo_params;
 	struct logical_volume *data_lv;
@@ -459,7 +459,7 @@ static int _vdo_target_present(struct cmd_context *cmd,
 		/* If stripe target was already detected, reuse its result */
 		if (!(segtype = get_segtype_from_string(cmd, SEG_TYPE_NAME_STRIPED)) ||
 		    !segtype->ops->target_present || !segtype->ops->target_present(cmd, NULL, NULL)) {
-			/* Linear/Stripe targer is for mapping LVs on top of single VDO volume. */
+			/* Linear/Stripe target is for mapping LVs on top of single VDO volume. */
 			if (!target_present(cmd, TARGET_NAME_LINEAR, 0) ||
 			    !target_present(cmd, TARGET_NAME_STRIPED, 0))
 				return 0;
