@@ -10,8 +10,6 @@
  * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-#include "tools/tool.h"
-
 #include "daemon-server.h"
 #include "daemon-log.h"
 
@@ -82,12 +80,12 @@ static int _type_interesting(log_state *s, int type) {
 	return 0;
 }
 
-void daemon_logf(log_state *s, int type, const char *fmt, ...) {
+void daemon_logf(log_state *s, int type, const char *format, ...) {
 	char *buf;
 	va_list ap;
 
-	va_start(ap, fmt);
-	if (dm_vasprintf(&buf, fmt, ap) >= 0) {
+	va_start(ap, format);
+	if (dm_vasprintf(&buf, format, ap) >= 0) {
 		daemon_log(s, type, buf);
 		free(buf);
 	} /* else return_0 */
@@ -116,7 +114,7 @@ void daemon_log_cft(log_state *s, int type, const char *prefix, const struct dm_
 	(void) dm_config_write_node(n, &_log_line, &b);
 }
 
-void daemon_log_multi(log_state *s, int type, const char *prefix, const char *msg)
+void daemon_log_multi(log_state *s, int type, const char *prefix, const char *message)
 {
 	struct log_line_baton b = { .s = s, .type = type, .prefix = prefix };
 	char *buf;
@@ -125,7 +123,7 @@ void daemon_log_multi(log_state *s, int type, const char *prefix, const char *ms
 	if (!_type_interesting(s, type))
 		return;
 
-	buf = strdup(msg);
+	buf = strdup(message);
 	pos = buf;
 
 	if (!buf)
