@@ -16,6 +16,8 @@
 #ifndef LIB_DMTARGETS_H
 #define LIB_DMTARGETS_H
 
+#include "libdm/libdevmapper.h"
+
 #include <inttypes.h>
 #include <sys/types.h>
 
@@ -69,6 +71,7 @@ struct dm_task {
 	int enable_checks;
 	int expected_errno;
 	int ioctl_errno;
+	int ima_measurement;
 
 	int record_timestamp;
 
@@ -77,7 +80,7 @@ struct dm_task {
 };
 
 struct cmd_data {
-	const char *name;
+	const char name[16];
 	const unsigned cmd;
 	const int version[3];
 };
