@@ -26,7 +26,7 @@ rand_bytes() {
 	chars="abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789"
 
 	dev_rand="/dev/urandom"
-	if test -r "$dev_rand"; then
+	if [[ -r "$dev_rand" ]]; then
 		# Note: 256-length($chars) == 194; 3 copies of $chars is 186 + 8 = 194.
 		head -c"$n" "$dev_rand" | tr -c "$chars" "01234567$chars$chars$chars"
 		return
@@ -40,7 +40,7 @@ rand_bytes() {
 	# Ensure that $data has length at least 50+$n
 	while :; do
 		len=${#data} # number of chars in $data
-		test "$n_plus_50" -le "$len" && break;
+		[[ "$n_plus_50" -le "$len" ]] && break;
 		data=$( (echo "$data"; eval "$cmds") 2>&1 | gzip )
 	done
 
@@ -57,7 +57,7 @@ mkdtemp() {
 	destdir=$1
 	template=$2
 
-        test -d "$destdir" || die "DIR ('$destdir') does not exist."
+	[[ -d "$destdir" ]] || die "DIR ('$destdir') does not exist."
 
 	case "$template" in
 		*XXXX) ;;
@@ -73,13 +73,13 @@ mkdtemp() {
 	case "$d" in "${destdir}"*);; *) fail=1;; esac
 
 	# It must have created the directory.
-	test -d "$d" || fail=1
+	[[ -d "$d" ]] || fail=1
 
 	# It must have 0700 permissions.
 	perms=$(ls -dgo "$d" 2>/dev/null) || fail=1
 	case "$perms" in drwx------*) ;; *) fail=1;; esac
 
-	test $fail = 0 && { echo "$d"; return; }
+	[[ $fail = 0 ]] && { echo "$d"; return; }
 
 	# If we reach this point, we'll have to create a directory manually.
 
@@ -96,7 +96,7 @@ mkdtemp() {
 		candidate_dir="$destdir/$base_template$X"
 		err=$(mkdir -m 0700 "$candidate_dir" 2>&1) && \
 			{ echo "$candidate_dir"; return; }
-		test $MAX_TRIES -le $i && break;
+		[[ $MAX_TRIES -le $i ]] && break;
 		i=$(( i + 1 ))
 	done
 	die "$err"
@@ -127,53 +127,57 @@ STACKTRACE() {
 
 	stacktrace
 
-	test "${LVM_TEST_PARALLEL:-0}" -eq 0 && test -z "$RUNNING_DMEVENTD" && \
-		test ! -f LOCAL_DMEVENTD && pgrep dmeventd >DPID 2>/dev/null  && {
-			echo "## ERROR: The test started dmeventd ($(< DPID)) unexpectedly."
-			kill "$(< DPID)"
-		}
+	if [[ "${LVM_TEST_PARALLEL:-0}" -eq 0 && -z "$RUNNING_DMEVENTD" && \
+		! -f LOCAL_DMEVENTD ]] && DPID=$(pgrep -n dmeventd 2>/dev/null); then
+		echo "## ERROR: The test started dmeventd ($DPID) unexpectedly."
+		kill "$DPID" 2>/dev/null || echo "## ERROR: Failed to kill dmeventd ($DPID)."
+	fi
 
 	# Get backtraces from coredumps
 	if which gdb &>/dev/null; then
 		# Check for all cores newer then TESTNAME file
 		# Assume users keep prefix 'core'
 		# TODO: possibly better integrate with coredumpctl & systemd
-		while IFS= read -r i; do
+		local cores=()
+		local IFS=$IFS_NL
+		cores=( $(find . "$(dirname "$(sysctl -n kernel.core_pattern)")" \
+			"/var/lib/systemd/coredump/" -name 'core*' -newer TESTNAME 2>/dev/null) ) || true
+
+		for i in "${cores[@]-}"; do
 			bin=$(gdb -batch -c "$i" 2>&1 | grep "generated by" | \
 			sed -e "s,.*generated by \`\([^ ']*\).*,\1,") || continue
-			{
-				echo bt full
-				echo l
-				echo quit
-			} > gdb_commands.txt || rm -f gdb_commands.txt
+			cat > gdb_commands.txt <<- EOF || rm -f gdb_commands.txt
+				bt full
+				l
+				quit
+			EOF
 
-			if test ! -s gdb_commands.txt ; then
-				echo "Out of disk space, can't check coredump $i generated by $bin."
-				continue
+			if [[ ! -s gdb_commands.txt ]]; then
+				echo "Out of disk space, cannot check coredump \"$i\" generated by \"$bin\"."
+				break
 			fi
 
 			echo "## Checking coredump: $i generated by $bin."
 			gdb -batch -c "$i" -x gdb_commands.txt "$(which "$bin")" 2>/dev/null | \
 			sed -e "s,^,## GDB:	," || continue
-		done < <(find . "$(dirname "$(sysctl -n kernel.core_pattern)")" \
-			"/var/lib/systemd/coredump/" -name 'core*' -newer TESTNAME 2>/dev/null || true)
+		done
 	fi
 
-	test -f SKIP_THIS_TEST && exit 200
+	[[ -f SKIP_THIS_TEST ]] && exit 200
 
-	test -z "$LVM_TEST_NODEBUG" && test -f TESTNAME && {
+	if [[ "${LVM_TEST_NODEBUG:-0}" -eq 0 && -f TESTNAME ]]; then
 		local name
 		local idx=0
 		for i in debug.log* ; do
-			test -f "$i" || break  # nothing is found (expands to debug.log*)
+			[[ -f "$i" ]] || break  # nothing is found (expands to debug.log*)
 			name=${i##debug.log_}
 			name=${name%%_*}
-			test "$name" = "DEBUG" && { name="$name$idx" ; idx=$(( idx + 1 )) ; }
+			[[ "$name" = "DEBUG" ]] && { name="$name$idx" ; idx=$(( idx + 1 )) ; }
 			echo "<======== Debug log $i ========>"
 			sed -e "s,^,## $name: ," "$i"
 			mv -f "$i" "debug_${i#debug.}"
 		done
-		if test -e strace.log ; then
+		if [[ -e strace.log ]]; then
 			echo "<======== Strace debug log ========>"
 			sed -e "s,^,## STRACE: ," strace.log
 		fi
@@ -189,10 +193,11 @@ STACKTRACE() {
 			echo "<======== Tree ========>"
 			dmsetup ls --tree | sed -e "s,^,## DMTREE:   ,"
 			echo "<======== Recursive list of $DM_DEV_DIR ========>"
-			ls -lR -I bsg -I bus -I char -Idma_heap -I dri \
+			ls -lR -I accel -I bsg -I bus -I char -I cpu \
+			   -I dma_heap -I dri \
 			   -I hugepages -I input -I mqueue \
 			   -I net -I pts -I shm -I snd \
-			   -I tty?* -I usb -I vfio -I vcs?* \
+			   -I tty?* -I usb -I v4l -I vfio -I vcs?* \
 			   -I virtio-ports \
 			   "$DM_DEV_DIR" | sed -e "s,^,## LS_LR:	,"
 			echo "<======== Udev DB content ========>"
@@ -204,29 +209,29 @@ STACKTRACE() {
 		df -h | sed -e "s,^,## DF_H:	,"
 		echo "<======== Script file \"$(< TESTNAME)\" ========>"
 		local script=$0
-		test -f "$script" || script="$TESTOLDPWD/$0"
+		[[ -f "$script" ]] || script="$TESTOLDPWD/$0"
 		awk '{print "## Line:", NR, "\t", $0}' "$script"
-	}
+	fi
 }
 
 init_udev_transaction() {
-	if test "$DM_UDEV_SYNCHRONIZATION" = 1; then
+	if [[ "$DM_UDEV_SYNCHRONIZATION" = 1 ]]; then
 		local cookie
 		cookie=$(dmsetup udevcreatecookie)
 		# Cookie is not generated if udev is not running!
-		test -z "$cookie" || export DM_UDEV_COOKIE=$cookie
+		[[ -z "$cookie" ]] || export DM_UDEV_COOKIE=$cookie
 	fi
 }
 
 finish_udev_transaction() {
-	if test "$DM_UDEV_SYNCHRONIZATION" = 1 && test -n "${DM_UDEV_COOKIE-}" ; then
+	if [[ "$DM_UDEV_SYNCHRONIZATION" = 1 && -n "${DM_UDEV_COOKIE-}" ]]; then
 		dmsetup udevreleasecookie || true
 		unset DM_UDEV_COOKIE
 	fi
 }
 
 teardown_udev_cookies() {
-	if test "$DM_UDEV_SYNCHRONIZATION" = 1; then
+	if [[ "$DM_UDEV_SYNCHRONIZATION" = 1 ]]; then
 		# Delete any cookies created more than 10 minutes ago
 		# and not used in the last 10 minutes.
 		# Log only non-zero semaphores count
@@ -248,7 +253,7 @@ dm_table() {
 
 skip() {
 	set +vx # debug off
-	if test "$#" -eq 0; then
+	if [[ "$#" -eq 0 ]]; then
 		stacktrace
 	else
 		echo -e "TEST SKIPPED:" "$@"
@@ -258,13 +263,14 @@ skip() {
 }
 
 get_real_devs() {
-	REAL_DEVICES=( $(<REAL_DEVICES) )
+	local IFS=$IFS_NL
+	REAL_DEVICES=( $(< REAL_DEVICES) ) || true
 	export REAL_DEVICES
 }
 
 get_devs() {
 	local IFS=$IFS_NL
-	DEVICES=( $(<DEVICES) )
+	DEVICES=( $(< DEVICES) ) || true
 	export DEVICES
 #	local DEVS=( $(<DEVICES) )
 #	eval "$1"'=("${DEVS[@]}")'
@@ -279,9 +285,9 @@ prepare_test_vars() {
 		eval "vg$i=\"${PREFIX}vg$i\""
 	done
 
-	if test -n "$LVM_TEST_DEVICE_LIST"; then
+	if [[ -n "${LVM_TEST_DEVICE_LIST-}" ]]; then
 		local count=0
-		while read path; do
+		while read -r path; do
 			count=$((  count + 1 ))
 			eval "dev$count=\"$path\""
 		done < "$LVM_TEST_DEVICE_LIST"
@@ -292,11 +298,11 @@ prepare_test_vars() {
 	fi
 }
 
-if test -z "${abs_top_builddir+varset}" && test -z "${installed_testsuite+varset}"; then
+if [[ -z "${abs_top_builddir+varset}" && -z "${installed_testsuite+varset}" ]]; then
     . lib/paths || die "something went wrong -- lib/paths is missing?"
 fi
 
-if test -z "${installed_testsuite+varset}"; then
+if [[ -z "${installed_testsuite+varset}" ]]; then
     case "$PATH" in
     *"$abs_top_builddir/test/lib"*) ;;
     *)
@@ -307,4 +313,4 @@ if test -z "${installed_testsuite+varset}"; then
     esac
 fi
 
-test -z "$PREFIX" || prepare_test_vars
+[[ -z "${PREFIX-}" ]] || prepare_test_vars
