@@ -17,10 +17,9 @@
 #   instead lvconvert --repair them?)
 # - linear LVs with bits missing are not activated
 
-SKIP_WITH_LVMLOCKD=1
-SKIP_WITH_LVMPOLLD=1
 
-. lib/inittest
+
+. lib/inittest --skip-with-lvmpolld
 
 aux prepare_vg 2
 
