@@ -12,11 +12,10 @@
 
 # Test single lv cache
 
-SKIP_WITH_LVMPOLLD=1
 
-. lib/inittest
+. lib/inittest --skip-with-lvmpolld
 
-aux have_cache 1 3 0 || skip
+aux have_cache 1 10 0 || skip
 aux have_thin 1 0 0 || skip
 
 aux prepare_devs 5 80
