@@ -16,7 +16,7 @@
 
 aux lvmconf "global/support_mirrored_mirror_log=1"
 
-aux prepare_pvs 5
+aux prepare_pvs 5 50
 get_devs
 
 # proper DEVRANGE needs to be set according to extent size
@@ -147,7 +147,7 @@ lvcreate -aey -l2 --type mirror -m2 -n $lv1 $vg "$dev1" "$dev2" "$dev5" "$dev3:$
 LVM_TEST_TAG="kill_me_$PREFIX" lvconvert -m+1 -b $vg/$lv1 "$dev4"
 # FIXME: Extra wait here for mirror upconvert synchronization
 # otherwise we may fail her on parallel upconvert and downconvert
-# lvconvert-mirror-updown.sh tests this errornous case separately
+# lvconvert-mirror-updown.sh tests this erroneous case separately
 lvconvert $vg/$lv1
 lvconvert -m-1 $vg/$lv1 "$dev2"
 lvconvert $vg/$lv1
@@ -162,7 +162,7 @@ lvcreate -aey -l2 --type mirror -m1 -n $lv1 $vg "$dev1" "$dev2" "$dev3:$DEVRANGE
 LVM_TEST_TAG="kill_me_$PREFIX" lvconvert -m+1 -b $vg/$lv1 "$dev4"
 # FIXME: Extra wait here for mirror upconvert synchronization
 # otherwise we may fail her on parallel upconvert and downconvert
-# lvconvert-mirror-updown.sh tests this errornous case separately
+# lvconvert-mirror-updown.sh tests this erroneous case separately
 lvconvert $vg/$lv1
 lvconvert -m-1 $vg/$lv1 "$dev2"
 lvconvert $vg/$lv1
@@ -177,7 +177,7 @@ lvcreate -aey -l2 --type mirror -m1 -n $lv1 $vg "$dev1" "$dev2" "$dev3:$DEVRANGE
 LVM_TEST_TAG="kill_me_$PREFIX" lvconvert -m+1 -b $vg/$lv1 "$dev4"
 # FIXME: Extra wait here for mirror upconvert synchronization
 # otherwise we may fail her on parallel upconvert and downconvert
-# lvconvert-mirror-updown.sh tests this errornous case separately
+# lvconvert-mirror-updown.sh tests this erroneous case separately
 lvconvert $vg/$lv1
 lvconvert -m-1 $vg/$lv1 "$dev2"
 lvconvert $vg/$lv1
@@ -245,19 +245,10 @@ lvremove -ff $vg
 
 # Linear to mirror with mirrored log using --alloc anywhere
 lvcreate -aey -l2 -n $lv1 $vg "$dev1"
-if test -e LOCAL_CLVMD; then
-# This is not supposed to work in cluster
-not lvconvert --type mirror -m +1 --mirrorlog mirrored --alloc anywhere $vg/$lv1 "$dev1" "$dev2"
-else
 lvconvert --type mirror -m +1 --mirrorlog mirrored --alloc anywhere $vg/$lv1 "$dev1" "$dev2"
 check mirror $vg $lv1
-fi
 lvremove -ff $vg
 
-
-if test -e LOCAL_CLVMD; then
-: # FIXME - cases which needs to be fixed to work in cluster
-else
 # Should not be able to add images to --nosync mirror
 # but should be able to after 'lvchange --resync'
 lvcreate -aey --type mirror -m 1 -l1 -n $lv1 $vg --nosync
@@ -303,7 +294,6 @@ lvcreate -l2 -n $lv1 $vg
 lvconvert --type mirror -i1 -m1 $vg/$lv1 | tee out
 grep -e "$vg/$lv1: Converted:" out || die "Missing sync info in foreground mode"
 lvremove -ff $vg
-fi
 
 
 #########################################################################
@@ -311,7 +301,7 @@ fi
 # Test that the correct devices remain in the mirror
 # Make $dev2 & $dev4  zero backend device so large mirrors can be user
 # without consuming any real space. Clearly such mirrors can't be read back
-# but tests here are validating possibilies of those conversions
+# but tests here are validating possibilities of those conversions
 #
 # Test pulling primary image before mirror in-sync (should fail)
 # Test pulling primary image after mirror in-sync (should work)
@@ -323,8 +313,8 @@ SHOULD=
 aux throttle_dm_mirror || SHOULD=should
 test "${LVM_VALGRIND:-0}" -eq 0 || SHOULD=should
 
-# Use large enough mirror that takes time to sychronize with small regionsize
-lvcreate -aey -L20 -Zn -Wn --type mirror --regionsize 4k -m2 -n $lv1 $vg "$dev1" "$dev2" "$dev4" "$dev3:$DEVRANGE"
+# Use large enough mirror that takes time to synchronize with small regionsize
+lvcreate -aey -L40 -Zn -Wn --type mirror --regionsize 4k -m2 -n $lv1 $vg "$dev1" "$dev2" "$dev4" "$dev3:$DEVRANGE"
 $SHOULD not lvconvert -m-1 $vg/$lv1 "$dev1" 2>&1 | tee out
 aux restore_dm_mirror
 $SHOULD grep "not in-sync" out
@@ -338,11 +328,10 @@ check linear $vg $lv1
 check lv_on $vg $lv1 "$dev4"
 lvremove -ff $vg
 
-
 aux throttle_dm_mirror || :
 # No parallel lvconverts on a single LV please
-# Use big enough mirror size and small regionsize to run on all test machines succesfully
-lvcreate -aey -Zn -Wn -L20 --type mirror --regionsize 4k -m1 -n $lv1 $vg "$dev1" "$dev2" "$dev3:0-8"
+# Use big enough mirror size and small regionsize to run on all test machines successfully
+lvcreate -aey -Zn -Wn -L40 --type mirror --regionsize 4k -m1 -n $lv1 $vg "$dev1" "$dev2" "$dev3:0-8"
 check mirror $vg $lv1
 check mirror_legs $vg $lv1 2
 
