@@ -1,5 +1,6 @@
-#!/bin/sh
-# Copyright (C) 2011-2012 Red Hat, Inc. All rights reserved.
+#!/usr/bin/env bash
+
+# Copyright (C) 2011-2016 Red Hat, Inc. All rights reserved.
 #
 # This copyrighted material is made available to anyone wishing to use,
 # modify, copy, or redistribute it subject to the terms and conditions
@@ -9,13 +10,12 @@
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-SKIP_WITH_LVMLOCKD=1
-SKIP_WITH_LVMPOLLD=1
 
-. lib/inittest
+
+. lib/inittest --skip-with-lvmpolld
 
 lv_devices() {
-	test $3 -eq $(get lv_devices $1/$2 | wc -w)
+	test "$3" -eq "$(get lv_devices "$1/$2" | wc -w)"
 }
 
 ########################################################
@@ -23,8 +23,13 @@ lv_devices() {
 ########################################################
 aux have_raid 1 3 0 || skip
 
+RAID4=""
+aux have_raid4 && RAID4=raid4
+
 aux prepare_pvs 6 20  # 6 devices for RAID10 (2-mirror,3-stripe) test
-vgcreate -s 512k $vg $(cat DEVICES)
+get_devs
+
+vgcreate $SHARED -s 512k "$vg" "${DEVICES[@]}"
 
 ###########################################
 # Create, wait for sync, remove tests
@@ -54,7 +59,7 @@ aux wait_for_sync $vg $lv1
 lvremove -ff $vg
 
 # Create RAID 4/5/6 (explicit 3-stripe + parity devs)
-for i in raid4 \
+for i in $RAID4 \
 	raid5 raid5_ls raid5_la raid5_rs raid5_ra \
 	raid6 raid6_zr raid6_nr raid6_nc; do
 
@@ -64,7 +69,7 @@ for i in raid4 \
 done
 
 # Create RAID 4/5/6 (explicit 3-stripe + parity devs) - Set min/max recovery
-for i in raid4 \
+for i in $RAID4 \
 	raid5 raid5_ls raid5_la raid5_rs raid5_ra \
 	raid6 raid6_zr raid6_nr raid6_nc; do
 
@@ -117,7 +122,7 @@ EAT_SIZE=$(get lv_field $vg/eat_space size)
 lvcreate --type raid1 -m 1 -l 100%FREE -an -Zn -n raid1 $vg "$dev1" "$dev2"
 check lv_field $vg/raid1 size "9.50m"
 # Ensure image size is the same as the RAID1 size
-check lv_field $vg/raid1 size $(get lv_field $vg/raid1_rimage_0 size -a)
+check lv_field $vg/raid1 size "$(get lv_field $vg/raid1_rimage_0 size -a)"
 # Amount remaining in dev2 should equal the amount taken by 'lv' in dev1
 check pv_field "$dev2" pv_free "$EAT_SIZE"
 lvremove -ff $vg/raid1
@@ -177,6 +182,22 @@ lvcreate --type raid6 -l3 -an -Zn -n raid6 $vg "$dev1" "$dev2" "$dev3" "$dev4" "
 lv_devices $vg raid6 5
 lvremove -ff $vg
 
+# Implicit count comes from total #PVs in VG (always 2 for mirror though)
+# Defaults -i2 even though more PVs listed
+lvcreate --type raid1 -l1 -an -Zn -n raid1 $vg
+lv_devices $vg raid1 2
+lvcreate --type raid5 -l2 -an -Zn -n raid5 $vg
+lv_devices $vg raid5 3
+lvcreate --type raid6 -l3 -an -Zn -n raid6 $vg
+lv_devices $vg raid6 5
+lvremove -ff $vg
+
+
+########################################################
+# Try again with backward compatible old logic applied #
+########################################################
+aux lvmconf 'allocation/raid_stripe_all_devices = 1'
+
 # Implicit count comes from total #PVs in VG (always 2 for mirror though)
 lvcreate --type raid1 -l1 -an -Zn -n raid1 $vg
 lv_devices $vg raid1 2
