@@ -15,10 +15,9 @@
 # Full CLI uses  --type
 # Shorthand CLI uses -H | --cache
 
-SKIP_WITH_LVMLOCKD=1
-SKIP_WITH_LVMPOLLD=1
 
-. lib/inittest
+
+. lib/inittest --skip-with-lvmpolld
 
 aux have_cache 1 3 0 || skip
 aux prepare_vg 5 8000
