@@ -26,10 +26,10 @@ lv_is_on_ ()
 
 	echo "Check if $lv is exactly on PVs" "${list_pvs[@]}"
 	rm -f out1 out2
-	printf "%s\n" "${list_pvs[@]}" | sort | uniq > out1
+	printf "%s\n" "${list_pvs[@]}" | sort -u > out1
 
 	lvs -a -o+devices $lv
-	get lv_devices "$lv" | sort | uniq > out2
+	get lv_devices "$lv" | sort -u > out2
 
 	diff --ignore-blank-lines out1 out2
 }
@@ -43,7 +43,7 @@ mimages_are_on_ ()
 	local i
 
 	echo "Check if mirror images of $lv are on PVs" "${list_pvs[@]}"
-	printf "%s\n" "${list_pvs[@]}" | sort | uniq | tee out1
+	printf "%s\n" "${list_pvs[@]}" | sort -u | tee out1
 
 	get lv_field_lv_ "$vg" lv_name -a | grep "${lv}_mimage_" | tee lvs_log
 	test -s lvs_log || return 1
@@ -54,7 +54,7 @@ mimages_are_on_ ()
 
 	for i in "${mimages[@]}"; do
 		get lv_devices "$vg/$i"
-	done | sort | uniq | tee out2
+	done | sort -u | tee out2
 
 	diff --ignore-blank-lines out1 out2
 }
@@ -124,7 +124,7 @@ recover_vg_()
 	pvscan --cache
 
 	pvcreate -ff "$@"
-	# wipefs -a "$@"
+	# aux wipefs_a "$@"
 	vgextend $vg "$@"
 
 	check_and_cleanup_lvs_
@@ -337,11 +337,13 @@ test_2way_mirror_plus_2_fail_3_()
 
 	aux disable_dev "${list_pvs[@]}"
 	vgreduce --removemissing --force $vg
-	lvs -a -o+devices $vg
+	lvs -a -o+devices,segtype $vg
 	eval dev=\$dev$n
-	not mimages_are_on_ $lv1 "$dev"
+	mimages_are_on_ $lv1 "$dev" && die "Mimages of $lv1 is using $dev"
 	lv_is_on_ $lv1 "$dev"
-	not mirrorlog_is_on_ $lv1 "$dev5"
+	if [[ $(get lv_field $vg/$lv1 "segtype") = "mirror" ]]; then
+		mirrorlog_is_on_ $lv1 "$dev5" && die "Mirror log of $lv1 is still using $dev5"
+	fi
 }
 
 for n in $(seq 1 4); do
@@ -367,7 +369,7 @@ mirrorlog_is_on_ $lv1 "$dev5"
 aux disable_dev "$dev5"
 vgreduce --removemissing --force $vg
 mimages_are_on_ $lv1 "$dev1" "$dev2"
-not mirrorlog_is_on_ $lv1 "$dev5"
+mirrorlog_is_on_ $lv1 "$dev5" && die "Mirror log of $lv1 is using $dev5"
 recover_vg_ "$dev5"
 
 #COMM "fail mirror log of 3-way (1 converting) mirrored LV"
@@ -379,7 +381,7 @@ mirrorlog_is_on_ $lv1 "$dev5"
 aux disable_dev "$dev5"
 vgreduce --removemissing --force $vg
 mimages_are_on_ $lv1 "$dev1" "$dev2" "$dev3"
-not mirrorlog_is_on_ $lv1 "$dev5"
+mirrorlog_is_on_ $lv1 "$dev5" && die "Mirror log of $lv1 is using $dev5"
 recover_vg_ "$dev5"
 
 # ---------------------------------------------------------------------
