@@ -15,10 +15,8 @@
 
 # Moving 2 LVs in VG variant
 
-SKIP_WITH_LVMLOCKD=1
-SKIP_WITH_CLVMD=1
 
-. lib/inittest
+. lib/inittest --skip-with-lvmlockd
 
 aux prepare_pvs 2 30
 
@@ -34,33 +32,16 @@ test_pvmove_resume() {
 	aux delay_dev "$dev2" 0 30 "$(get first_extent_sector "$dev2"):"
 
 	pvmove -i5 "$dev1" &
-	PVMOVE=$!
+	PVMOVE_PID=$!
 	aux wait_pvmove_lv_ready "$vg-pvmove0"
-	kill $PVMOVE
+	kill $PVMOVE_PID
 
 	test -e LOCAL_LVMPOLLD && aux prepare_lvmpolld
-	wait
+	wait "$PVMOVE_PID" || true
 	aux remove_dm_devs "$vg-$lv1" "$vg-$lv2" "$vg-pvmove0"
 
 	check lv_attr_bit type $vg/pvmove0 "p"
 
-	if test -e LOCAL_CLVMD ; then
-		# giveup all clvmd locks (faster then restarting clvmd)
-		# no deactivation happen, nodes are already removed
-		#vgchange -an $vg
-		# FIXME: However above solution has one big problem
-		# as clvmd starts to abort on internal errors on various
-		# errors, based on the fact pvmove is killed -9
-		# Restart clvmd
-		kill "$(< LOCAL_CLVMD)"
-		for i in {1..100} ; do
-			test $i -eq 100 && die "Shutdown of clvmd is too slow."
-			test -e "$CLVMD_PIDFILE" || break
-			sleep .1
-		done # wait for the pid removal
-		aux prepare_clvmd
-	fi
-
 	# call resume function (see below)
 	# with expected number of spawned
 	# bg polling as parameter
@@ -86,14 +67,17 @@ lvchange_single() {
 
 lvchange_all() {
 	LVM_TEST_TAG="kill_me_$PREFIX" lvchange -aey $vg/$lv1 $vg/$lv2
+	local count=$1
 
+	# TODO: currently lvm2 is spawning polling process for each LV
 	# we don't want to spawn more than $1 background pollings
+	count=2
+
 	if test -e LOCAL_LVMPOLLD; then
 		aux lvmpolld_dump | tee lvmpolld_dump.txt
-		aux check_lvmpolld_init_rq_count 1 "$vg/pvmove0" || should false
+		aux check_lvmpolld_init_rq_count "$count" "$vg/pvmove0" || should false
 	elif test -e HAVE_DM_DELAY; then
-		test "$(aux count_processes_with_tag)" -eq "$1" || {
-			# FIXME: currently lvm2 is spawning polling process for each LV
+		test "$(aux count_processes_with_tag)" -eq "$count" || {
 			echo "Lvchange spawns pvmove per activated LV"
 		}
 	fi
