@@ -11,17 +11,16 @@
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #
-# Testcase for bugzilla #621173 
-# excercises partition table scanning code path
+# Testcase for bugzilla #621173
+# exercises partition table scanning code path
 #
 
 
 
-SKIP_WITH_LVMPOLLD=1
 
 LVM_TEST_CONFIG_DEVICES="types = [\"device-mapper\", 142]"
 
-. lib/inittest
+. lib/inittest --skip-with-lvmpolld
 
 which sfdisk || skip
 
@@ -32,5 +31,4 @@ pvs "$dev1"
 # create small partition table
 echo "1 2" | sfdisk --force "$dev1"
 
-aux notify_lvmetad "$dev1"
 not pvs "$dev1"
