@@ -11,14 +11,13 @@
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 
-SKIP_WITH_LVMPOLLD=1
 
-. lib/inittest
+. lib/inittest --skip-with-lvmpolld
 
 aux prepare_devs 4
 get_devs
 
-if test -n "$LVM_TEST_LVM1" ; then
+if [[ "${LVM_TEST_LVM1:-0}" != 0 ]] ; then
 mdatypes='1 2'
 else
 mdatypes='2'
@@ -90,7 +89,7 @@ aux disable_dev "$dev1"
 #pvcreate -ff -y "$dev1"
 # vgreduce rejects --removemissing --mirrorsonly --force when nonmirror lv lost too
 #not vgreduce -c n --removemissing --mirrorsonly --force $vg1
-# CHECKME - command above was rejected becuase of '-c n'
+# CHECKME - command above was rejected because of '-c n'
 vgreduce --removemissing --mirrorsonly --force $vg1
 
 aux enable_dev "$dev1"
