@@ -1,4 +1,4 @@
-// Copyright (C) 2018 Red Hat, Inc. All rights reserved.
+// Copyright (C) 2018-2025 Red Hat, Inc. All rights reserved.
 //
 // This file is part of LVM2.
 //
@@ -530,8 +530,8 @@ static void test_remove_calls_dtr(void *fixture)
 		for (i = 0; i < DTR_COUNT; i++) {
 			bool found = false;
 			do {
-				v.n = i;
 				uint8_t *k = keys + (i * 3);
+				v.n = i;
 				_gen_key(k, k + 3);
 				if (!radix_tree_lookup(rt, k, 3, &v)) {
 					T_ASSERT(radix_tree_insert(rt, k, 3, v));
@@ -584,8 +584,8 @@ static void test_destroy_calls_dtr(void *fixture)
 		for (i = 0; i < DTR_COUNT; i++) {
 			bool found = false;
 			do {
-				v.n = i;
 				uint8_t *k = keys + (i * 3);
+				v.n = i;
 				_gen_key(k, k + 3);
 				if (!radix_tree_lookup(rt, k, 3, &v)) {
 					T_ASSERT(radix_tree_insert(rt, k, 3, v));
@@ -803,11 +803,66 @@ static void __invalidate(struct radix_tree *rt, int fd)
 	T_ASSERT(radix_tree_is_well_formed(rt));
 }
 
+static void _generate_radix_test_sub_pattern(struct radix_tree *rt, int idx)
+{
+	int j;
+
+	for (j = 5; j < 8; ++j)  {
+		__lookup_fails(rt, idx, j);
+		__insert(rt, idx, j, j + 195);
+		__lookup_matches(rt, idx, j, j + 195);
+	}
+}
+
+/*
+ * Generate the similar test patterns as rt_case1.c but algorithmically.
+ */
+static void _generate_radix_test_pattern(struct radix_tree *rt)
+{
+	int fd;
+
+	for (fd = 6; fd <= 205; fd++) {
+		__lookup_fails(rt, fd, 0);
+		__insert(rt, fd, 0, fd - 6);
+		switch (fd) {
+		case 46:
+		case 65:
+			_generate_radix_test_sub_pattern(rt, fd);
+		}
+	}
+
+	for (fd = 6; fd <= 205; fd++) {
+		__lookup_matches(rt, fd, 0, fd - 6);
+		__invalidate(rt, fd);
+	}
+
+	for (fd = 6; fd <= 205; fd++) {
+		__lookup_fails(rt, fd, 0);
+		__insert(rt, fd, 0, fd + 202);
+	}
+
+	for (fd = 6; fd <= 205; fd++) {
+		__lookup_matches(rt, fd, 0, fd + 202);
+		__invalidate(rt, fd);
+	}
+
+	for (fd = 6; fd <= 23; fd++) {
+		__lookup_fails(rt, fd, 0);
+		__insert(rt, fd, 0, fd + 402);
+	}
+
+	for (fd = 6; fd <= 13; fd++) {
+		__lookup_matches(rt, fd, 0, fd + 402);
+		__invalidate(rt, fd);
+	}
+}
+
 static void test_bcache_scenario3(void *fixture)
 {
 	struct radix_tree *rt = fixture;
 
-	#include "test/unit/rt_case1.c"
+	/* Generate test patterns algorithmically instead of static inclusion */
+	_generate_radix_test_pattern(rt);
 }
 
 static bool _uniq_visit(struct radix_tree_iterator *it,
