@@ -156,7 +156,7 @@ static int _lvchange_monitoring(struct cmd_context *cmd,
 			log_verbose("Monitoring LV %s", display_lvname(lv));
 		else
 			log_verbose("Unmonitoring LV %s", display_lvname(lv));
-		if (!monitor_dev_for_events(cmd, lv, 0, dmeventd_monitor_mode())) {
+		if (!monitor_dev_for_events(cmd, lv, 0, dmeventd_monitor_mode() ? 1 : 0)) {
 			log_error("Failed to change monitoring for %s volume.",
 				  display_lvname(lv));
 			return 0;
