@@ -86,6 +86,7 @@ static int _update_vg(struct cmd_context *cmd, struct volume_group *vg,
 		}
 	}
 
+	/* coverity[unreachable] intentional single iteration to get first item */
 	dm_list_iterate_items(devl, &vp->new_devs) {
 		/* device arg is not in the VG. */
 		log_error("Device %s was not found in VG %s.", dev_name(devl->dev), vg->name);
@@ -116,6 +117,9 @@ static int _update_vg(struct cmd_context *cmd, struct volume_group *vg,
 	vg->lock_args = NULL;
 	vg->system_id = cmd->system_id ? dm_pool_strdup(vg->vgmem, cmd->system_id) : NULL;
 
+	/* The PR ability/settings of the orginal dev may not work on the cloned dev. */
+	vg->pr = 0;
+
 	dm_list_iterate_items(pvl, &vg->pvs) {
 		if (!(new_pvl = dm_pool_zalloc(vg->vgmem, sizeof(*new_pvl))))
 			goto_bad;
@@ -207,7 +211,7 @@ int vgimportclone(struct cmd_context *cmd, int argc, char **argv)
 	const char *vgname;
 	char base_vgname[NAME_LEN] = { 0 };
 	char tmp_vgname[NAME_LEN] = { 0 };
-	uint32_t lockd_state = 0;
+	struct lockd_state lks = { 0 };
 	uint32_t error_flags = 0;
 	unsigned int vgname_count;
 	int ret = ECMD_FAILED;
@@ -223,6 +227,8 @@ int vgimportclone(struct cmd_context *cmd, int argc, char **argv)
 	vp.import_devices = arg_is_set(cmd, importdevices_ARG);
 	vp.import_vg = arg_is_set(cmd, import_ARG);
 
+	cmd->disable_pr_required = 1;
+
 	if (!lock_global(cmd, "ex"))
 		return ECMD_FAILED;
 
@@ -408,7 +414,7 @@ int vgimportclone(struct cmd_context *cmd, int argc, char **argv)
 			goto out;
 		}
 		if (strcmp(vgname, vp.old_vgname)) {
-			(void) dm_strncpy(tmp_vgname, base_vgname, NAME_LEN);
+			dm_strncpy(tmp_vgname, base_vgname, sizeof(tmp_vgname));
 			vgname_count = 0;
 		} else {
 			/* Needed when basename matches old name, and PV is not a duplicate
@@ -474,7 +480,7 @@ retry_name:
 	cmd->can_use_one_scan = 1;
 	cmd->include_exported_vgs = 1;
 
-	vg = vg_read(cmd, vp.old_vgname, NULL, READ_WITHOUT_LOCK | READ_FOR_UPDATE, lockd_state, &error_flags, &error_vg);
+	vg = vg_read(cmd, vp.old_vgname, NULL, READ_WITHOUT_LOCK | READ_FOR_UPDATE, &lks, &error_flags, &error_vg);
 	if (!vg) {
 		log_error("Failed to read VG %s from devices being imported.", vp.old_vgname);
 		unlock_vg(cmd, NULL, vp.old_vgname);
