@@ -14,6 +14,7 @@
  */
 
 #include "tools.h"
+#include "lib/device/persist.h"
 
 struct vgrename_params {
 	const char *vg_name_old;
@@ -40,6 +41,7 @@ static int _vgrename_single(struct cmd_context *cmd, const char *vg_name,
 	struct vgrename_params *vp = (struct vgrename_params *) handle->custom_handle;
 	char old_path[PATH_MAX];
 	char new_path[PATH_MAX];
+	char vgid[ID_LEN + 1] __attribute__((aligned(8))) = { 0 };
 	struct id id;
 	const char *name;
 	char *dev_dir;
@@ -69,10 +71,13 @@ static int _vgrename_single(struct cmd_context *cmd, const char *vg_name,
 		return ECMD_FAILED;
 	}
 
-	if (id_read_format_try(&id, vp->vg_name_new) &&
-	    (name = lvmcache_vgname_from_vgid(cmd->mem, (const char *)&id))) {
-		log_error("New VG name \"%s\" matches the UUID of existing VG %s", vp->vg_name_new, name);
-		return ECMD_FAILED;
+	if (id_read_format_try(&id, vp->vg_name_new)) {
+		memcpy(vgid, &id, ID_LEN);
+
+		if ((name = lvmcache_vgname_from_vgid(cmd->mem, vgid))) {
+			log_error("New VG name \"%s\" matches the UUID of existing VG %s", vp->vg_name_new, name);
+			return ECMD_FAILED;
+		}
 	}
 
 	/*
@@ -103,14 +108,14 @@ static int _vgrename_single(struct cmd_context *cmd, const char *vg_name,
 
 	dev_dir = cmd->dev_dir;
 
-	if (!archive(vg))
-		goto error;
-
 	if (!lockd_rename_vg_before(cmd, vg)) {
 		stack;
 		goto error;
 	}
 
+	if (vg->pr)
+		persist_key_file_rename(vg, vg_name, vp->vg_name_new);
+
 	/* Change the volume group name */
 	vg_rename(cmd, vg, vp->vg_name_new);
 
@@ -144,8 +149,6 @@ static int _vgrename_single(struct cmd_context *cmd, const char *vg_name,
 
 	lockd_rename_vg_final(cmd, vg, 1);
 
-	if (!backup(vg))
-		stack;
 	if (!backup_remove(cmd, vg_name))
 		stack;
 
@@ -183,7 +186,7 @@ int vgrename(struct cmd_context *cmd, int argc, char **argv)
 	vg_name_new = skip_dev_dir(cmd, argv[1], NULL);
 
 	if (!validate_vg_rename_params(cmd, vg_name_old, vg_name_new))
-		return_0;
+		return_ECMD_FAILED;
 
 	if (!(vp.vg_name_old = dm_pool_strdup(cmd->mem, vg_name_old)))
 		return_ECMD_FAILED;
@@ -191,10 +194,11 @@ int vgrename(struct cmd_context *cmd, int argc, char **argv)
 	if (!(vp.vg_name_new = dm_pool_strdup(cmd->mem, vg_name_new)))
 		return_ECMD_FAILED;
 
-	/* Needed change the global VG namespace. */
-	if (!lockd_gl(cmd, "ex", LDGL_UPDATE_NAMES))
+	if (!lock_global(cmd, "ex"))
 		return_ECMD_FAILED;
 
+	clear_hint_file(cmd);
+
 	/*
 	 * Special case where vg_name_old may be a UUID:
 	 * If vg_name_old is a UUID, then process_each may
@@ -232,8 +236,7 @@ int vgrename(struct cmd_context *cmd, int argc, char **argv)
 
 	handle->custom_handle = &vp;
 
-	ret = process_each_vg(cmd, 0, NULL, vg_name_old, NULL,
-			      READ_FOR_UPDATE | READ_ALLOW_EXPORTED,
+	ret = process_each_vg(cmd, 0, NULL, vg_name_old, NULL, READ_FOR_UPDATE,
 			      0, handle, _vgrename_single);
 
 	/* Needed if process_each_vg returns error before calling _single. */
